@@ -2,9 +2,9 @@
 # -*- coding: UTF-8 -*-
 # vim: expandtab sw=4 ts=4 sts=4:
 #
-# Copyright © 2003 - 2016 Michal Čihař <michal@cihar.com>
+# Copyright © 2003 - 2017 Michal Čihař <michal@cihar.com>
 #
-# This file is part of python-gammu <http://wammu.eu/python-gammu/>
+# This file is part of python-gammu <https://wammu.eu/python-gammu/>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -37,7 +37,7 @@ def callback(state_machine, callback_type, data):
     @param data: event data
     @type data: hash
     '''
-    print('Received incoming event type %s, data:' % callback_type)
+    print('Received incoming event type {0}, data:'.format(callback_type))
     print(data)
 
 
@@ -77,7 +77,7 @@ def main():
     print('Press Ctrl+C to interrupt')
     while 1:
         signal = state_machine.GetSignalQuality()
-        print('Signal is at %d%%' % signal['SignalPercent'])
+        print('Signal is at {0:d}%'.format(signal['SignalPercent']))
         time.sleep(1)
 
 if __name__ == '__main__':
