@@ -1,9 +1,9 @@
 # -*- coding: UTF-8 -*-
 # vim: expandtab sw=4 ts=4 sts=4:
 #
-# Copyright © 2003 - 2016 Michal Čihař <michal@cihar.com>
+# Copyright © 2003 - 2017 Michal Čihař <michal@cihar.com>
 #
-# This file is part of python-gammu <http://wammu.eu/python-gammu/>
+# This file is part of python-gammu <https://wammu.eu/python-gammu/>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -26,7 +26,9 @@ import os
 import os.path
 import threading
 import time
+import platform
 import sqlite3
+import unittest
 
 
 MESSAGE_1 = {
@@ -54,8 +56,10 @@ def get_script():
         dbver = 14
     elif version < (1, 37, 90):
         dbver = 15
-    else:
+    elif version < (1, 38, 5):
         dbver = 16
+    else:
+        dbver = 17
 
     print('Gammu version {0}, SMSD DB version {1}'.format(version, dbver))
 
@@ -68,6 +72,8 @@ def get_script():
 
 class SMSDDummyTest(DummyTest):
     def setUp(self):
+        if platform.system() == 'Windows':
+            raise unittest.SkipTest('SMSD testing not supported on Windows (no DBI driver)')
         super(SMSDDummyTest, self).setUp()
         database = sqlite3.connect(
             os.path.join(self.test_dir, 'smsd.db')
@@ -113,14 +119,14 @@ class SMSDDummyTest(DummyTest):
             self.assertEqual(
                 status['Received'],
                 2,
-                'Messages were not received as expected (%d)!' %
-                status['Received']
+                'Messages were not received as expected ({0:d})!'.format(
+                status['Received'])
             )
             self.assertEqual(
                 status['Sent'],
                 2,
-                'Messages were not sent as expected (%d)!' %
-                status['Sent']
+                'Messages were not sent as expected ({0:d})!'.format(
+                status['Sent'])
             )
 
             time.sleep(1)
